[VOL-3748] Support periodical audit of mib data sync (MDS) counter

Change-Id: Ifb61d98dca1285de70ac8fdcda4bb673374c6e07
diff --git a/internal/pkg/onuadaptercore/omci_vlan_config.go b/internal/pkg/onuadaptercore/omci_vlan_config.go
index 42a35f5..6725098 100644
--- a/internal/pkg/onuadaptercore/omci_vlan_config.go
+++ b/internal/pkg/onuadaptercore/omci_vlan_config.go
@@ -77,7 +77,7 @@
 )
 
 const (
 	// events of config PON ANI port FSM
 	vlanEvStart           = "vlanEvStart"
 	vlanEvWaitTechProf    = "vlanEvWaitTechProf"
 	vlanEvContinueConfig  = "vlanEvContinueConfig"
@@ -97,7 +97,7 @@
 )
 
 const (
 	// states of config PON ANI port FSM
 	vlanStDisabled        = "vlanStDisabled"
 	vlanStStarting        = "vlanStStarting"
 	vlanStWaitingTechProf = "vlanStWaitingTechProf"
@@ -110,6 +110,7 @@
 	vlanStCleanupDone     = "vlanStCleanupDone"
 	vlanStResetting       = "vlanStResetting"
 )
+const cVlanFsmIdleState = vlanStConfigDone
 
 type uniVlanRuleParams struct {
 	TpID         uint8  `json:"tp_id"`
@@ -77,7 +77,7 @@
 
 const (
-	// events of config PON ANI port FSM
+	// events of config UNI port VLAN FSM
 	vlanEvStart           = "vlanEvStart"
 	vlanEvWaitTechProf    = "vlanEvWaitTechProf"
@@ -97,7 +97,7 @@
 
 const (
-	// states of config PON ANI port FSM
+	// states of config UNI port VLAN FSM
 	vlanStDisabled        = "vlanStDisabled"
 	vlanStStarting        = "vlanStStarting"